import logging
import typer

import systemd.journal

from citadel.mqtt import Configuration
from . import Sleep

def main(\
        mqtt_user: str = typer.Option(... , envvar="DEVICES_MQTT_USER"),\
        mqtt_pwd: str = typer.Option(... ,  envvar="DEVICES_MQTT_PWD"),\
        mqtt_host: str = typer.Option(... , envvar="DEVICES_MQTT_HOST"),\
        mqtt_port: int = typer.Option(... , envvar="DEVICES_MQTT_PORT"),\
        is_systemd: bool = typer.Option(False, help="Is running as systemd unit", envvar="LAUNCHED_BY_SYSTEMD")\
        ):

    if is_systemd:
        logger = logging.getLogger()
        logger.setLevel(logging.DEBUG)
        logger.addHandler(systemd.journal.JournalHandler())
    else:
        logger = logging.getLogger()
        logger.setLevel(logging.DEBUG)
        # create console handler and set level to debug
        ch = logging.StreamHandler()
        ch.setLevel(logging.DEBUG)
        # create formatter
        formatter = logging.Formatter('%(asctime)s - %(name)s - %(levelname)s - %(message)s')
        # add formatter to ch
        ch.setFormatter(formatter)
        # add ch to logger
        logger.addHandler(ch)

    class Config:
        user = mqtt_user
        password = mqtt_pwd
        host = mqtt_host
        port = mqtt_port

    scene = Sleep(Config)
    scene.start()

if __name__ == "__main__":
    typer.run(main)
